@@ -14,10 +14,10 @@
 #include <QStackedWidget>
 #include <QVBoxLayout>
 
-#include <kaction.h>
-#include <kicon.h>
+#include <QAction>
+#include <QIcon>
 #include <kstandardgameaction.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "diceswidget.h"
 
@@ -27,9 +27,9 @@ lateralWidget::lateralWidget(QWidget *parent) : QWidget(parent), m_demoMode(fals
 	m_rolls = new QLabel(this);
 	m_dices = new dicesWidget(this);
 	m_buttons = new QStackedWidget(this);
-	m_rollButton = new QPushButton(KIcon( QLatin1String( "roll") ), i18n("&Roll" ), this);
+	m_rollButton = new QPushButton(QIcon::fromTheme( QLatin1String( "roll") ), i18n("&Roll" ), this);
 	
-	KAction *dummyAction = KStandardGameAction::gameNew(0, 0, 0);
+	QAction *dummyAction = KStandardGameAction::gameNew(0, 0, 0);
 	m_newGameButton = new QPushButton(dummyAction->icon(), dummyAction->text(), this);
 	delete dummyAction;
 
@@ -43,9 +43,9 @@ lateralWidget::lateralWidget(QWidget *parent) : QWidget(parent), m_demoMode(fals
 	lay -> addWidget(m_buttons);
 	lay -> addStretch(1);
 
-	connect(m_rollButton, SIGNAL(clicked(bool)), this, SLOT(roll()));
-	connect(m_rollButton, SIGNAL(clicked(bool)), this, SLOT(unhighlightAllDice()));
-	connect(m_newGameButton, SIGNAL(clicked(bool)), this, SLOT(newGame()));
+	connect(m_rollButton, &QPushButton::clicked, this, &lateralWidget::roll);
+	connect(m_rollButton, &QPushButton::clicked, this, &lateralWidget::unhighlightAllDice);
+	connect(m_newGameButton, &QPushButton::clicked, this, &lateralWidget::newGame);
 	
 	nextTurn();
 }
@@ -199,4 +199,4 @@ void lateralWidget::updateRollLabel()
 	if (!m_demoMode) setEnabled(m_roll != 3);
 }
 
-#include "lateralwidget.moc"
+
